# Changelog

## [stormi-v0.1.2-beta.1](https://github.com/pinellolab/stormi/compare/stormi-v0.1.1...stormi-v0.1.2-beta.1) (2025-03-19)

### Bug Fixes

* **pyproject:** `0.1.1` -> `0.1.2b1` ([f14b41e](https://github.com/pinellolab/stormi/commit/f14b41e2f2cadc81b4c3a85125f97241be3665c0))
